@@ -1,6 +1,9 @@
 package Acme::KeyboardMarathon;
+$Acme::KeyboardMarathon::VERSION = '1.19';
 
 use Carp;
+use Data::Dumper;
+use Math::BigInt;
 
 use warnings;
 use strict;
@@ -11,12 +14,10 @@ sub new {
   my $self = {};
   bless($self,$class);
 
-  $Acme::KeyboardMarathon::VERSION = '1.18';
-
   # all measures in cm
 
-  my $DEPRESS_CONSTANT = '0.25';
-  my $SHIFT_DISTANCE = '2';
+  my $DEPRESS_CONSTANT = 0.25;
+  my $SHIFT_DISTANCE = 2;
 
   my %basic_distances = ( # basic distance traveled horizontally for a key
        '0'   => q{AaSsDdFfJjKkLl;: },
@@ -36,25 +37,30 @@ sub new {
 
   for my $hdist ( keys %basic_distances ) {
     for my $key ( split '', $basic_distances{$hdist} ) {
-      $self->{k}->{$key} = $hdist + $DEPRESS_CONSTANT + ( $shifted{$key} ? $SHIFT_DISTANCE : 0 );
+      $self->{k}->{$key} = 100 * # Storing in 100ths of a CM to avoid floats
+        ( $hdist + $DEPRESS_CONSTANT + ( $shifted{$key} ? $SHIFT_DISTANCE : 0 ) );
     }
   }
 
+  #print Dumper($self->{k});
   return $self;
 }
 
 sub distance {
   my @args = @_;
   my $self = shift @args;
-  my $distance = 0;
+  my $distance = Math::BigInt->bzero();
   while ( my $chunk = shift @args ) {
     croak "FAR OUT! A REFERENCE: $chunk" if ref $chunk;
     for my $char ( split '', $chunk ) {
-      carp "WHOAH! I DON'T KNOW WHAT THIS IS: [$char]\n" and next unless defined $self->{k}->{$char};
+      unless ( defined $self->{k}->{$char} ) {
+        carp "WHOAH! I DON'T KNOW WHAT THIS IS: [$char] assigning it a 2.5 cm distance\n";
+        $self->{k}->{$char} = 2.5 * 100; # 100ths of a CM
+      }
       $distance += $self->{k}->{$char};
     }
   }
-  return $distance;
+  return int( $distance->as_int() / 100 );
 }
 
 1;
@@ -144,7 +150,7 @@ diacritics later, so I can feel better while still ignoring UTF's existence.
 
 =head1 VERSION
 
-	Acme::KeyboardMarathon v1.18 (2014/03/11)
+	Acme::KeyboardMarathon v1.19 (2014/03/19)
 
 =head1 COPYRIGHT
 
